// use system colours
pref("browser.display.use_system_colors", true);
//pref("browser.display.use_document_colors", false);

